@@ -35,7 +35,7 @@
 /* #undef WITH_MACAUDIO */
 /* #undef WITH_OSS */
 #define WITH_ALSA
-#define WITH_PULSE
+/* #undef WITH_PULSE */
 /* #undef WITH_IOSAUDIO */
 /* #undef WITH_OPENSLES */
 /* #undef WITH_GSM */
@@ -62,7 +62,7 @@
 
 #define WITH_CHANNELS
 #define WITH_CLIENT_CHANNELS
-/* #undef WITH_SERVER_CHANNELS */
+#define WITH_SERVER_CHANNELS
 
 /* #undef WITH_CHANNEL_GFXREDIR */
 /* #undef WITH_CHANNEL_RDPAPPLIST */
@@ -218,7 +218,7 @@
 /* #undef WITH_DEBUG_RINGBUFFER */
 
 /* Proxy */
-/* #undef WITH_PROXY_MODULES */
+#define WITH_PROXY_MODULES
 /* #undef WITH_PROXY_EMULATE_SMARTCARD */
 
 /** If defined linux/vm_sockets.h support is available.
